import time

import anyio
from asyncer import asyncify, syncify


async def do_async_work(name: str):
    await anyio.sleep(1)
    return f"Hello, {name}"


def do_sync_work(name: str):
    time.sleep(1)
    message = syncify(do_async_work, raise_sync_error=False)(name=name)
    return message


async def main():
    message = await asyncify(do_sync_work)(name="World")
    print(message)


def sync_main():
    message = do_sync_work(name="Sync World")
    print(message)


anyio.run(main)
sync_main()



import anyio
import asyncer


async def do_work(name: str):
    await anyio.sleep(1)
    return f"Hello, {name}"


async def main(name: str):
    result = await do_work(name=name)
    return result


result = asyncer.runnify(main)(name="World")
print(result)



__version__ = "0.0.8"

from ._main import PendingValueException as PendingValueException
from ._main import SoonValue as SoonValue
from ._main import TaskGroup as TaskGroup
from ._main import asyncify as asyncify
from ._main import create_task_group as create_task_group
from ._main import runnify as runnify
from ._main import syncify as syncify



from typing import Any, Callable, Dict, List, Union


def get_testing_print_function(
    calls: List[List[Union[str, Dict[str, Any]]]],
) -> Callable[..., Any]:
    def new_print(*args):
        data = []
        for arg in args:
            data.append(arg)
        calls.append(data)

    return new_print



import sys
from unittest.mock import patch

import asyncer
import pytest

if sys.version_info < (3, 11):
    from exceptiongroup import ExceptionGroup

from ...conftest import get_testing_print_function


def test_tutorial():
    calls = []

    new_print = get_testing_print_function(calls)

    with patch("builtins.print", new=new_print):
        with pytest.raises((ExceptionGroup, asyncer.PendingValueException)) as e:
            from docs_src.tutorial.soonify_return import tutorial002 as mod

            # Avoid autoflake removing this import
            assert mod  # pragma: nocover
        if isinstance(e.value, ExceptionGroup):
            assert isinstance(e.value.exceptions[0], asyncer.PendingValueException)
        else:
            assert isinstance(e.value, asyncer.PendingValueException)
    assert calls == []



import anyio


async def do_work(name: str):
    await anyio.sleep(1)
    print(f"Hello, {name}")


async def get_data():
    await do_work(name="Yury")
    await do_work(name="Nathaniel")
    await do_work(name="Alex")


async def main():
    await get_data()


anyio.run(main)



from unittest.mock import patch

from ...conftest import get_testing_print_function


def test_tutorial():
    calls = []

    new_print = get_testing_print_function(calls)

    with patch("builtins.print", new=new_print):
        from docs_src.tutorial.syncify import tutorial001 as mod

        assert mod
    assert calls == [["Hello, World"]]



import time

import anyio
from asyncer import asyncify


def do_sync_work(name: str):
    time.sleep(1)
    return f"Hello, {name}"


async def main():
    message = await asyncify(do_sync_work)(name="World")
    print(message)


anyio.run(main)



import anyio
import asyncer


async def do_work(name: str):
    await anyio.sleep(1)
    print(f"Hello, {name}")


async def get_data():
    async with asyncer.create_task_group() as task_group:
        task_group.soonify(do_work)(name="Yury")
        task_group.soonify(do_work)(name="Nathaniel")
        task_group.soonify(do_work)(name="Alex")


async def main():
    await get_data()


anyio.run(main)



import anyio
import asyncer


async def do_work(name: str):
    await anyio.sleep(1)
    message = f"Hello, {name}"
    return message


async def get_data():
    async with asyncer.create_task_group() as task_group:
        soon_value1 = task_group.soonify(do_work)(name="Yury")
        await anyio.sleep(2)
        if soon_value1.ready:
            print(f"Preview value1: {soon_value1.value}")
        soon_value2 = task_group.soonify(do_work)(name="Nathaniel")
        soon_value3 = task_group.soonify(do_work)(name="Alex")

    data = [soon_value1.value, soon_value2.value, soon_value3.value]
    return data


async def main():
    data = await get_data()
    for message in data:
        print(message)


anyio.run(main)



import anyio


async def do_work(name: str):
    await anyio.sleep(1)
    return f"Hello, {name}"


async def main():
    message = await do_work(name="World")
    return message


result = anyio.run(main)
print(result)



import warnings

import anyio
import pytest
from asyncer import asyncify


def test_cancellable_warns():
    def do_async_work():
        return "Hello World!"

    async def main():
        result = await asyncify(do_async_work, cancellable=True)()
        return result

    with pytest.warns(DeprecationWarning) as record:
        result = anyio.run(main)
    assert isinstance(record[0].message, Warning)
    assert (
        "The `cancellable=` keyword argument to `asyncer.asyncify()` is "
        "deprecated since Asyncer 0.0.8" in record[0].message.args[0]
    )
    assert result == "Hello World!"


def test_abandon_on_cancel_no():
    def do_async_work():
        return "Hello World!"

    async def main():
        result = await asyncify(do_async_work, abandon_on_cancel=True)()
        return result

    with warnings.catch_warnings():
        warnings.simplefilter("error")
        result = anyio.run(main)
    assert result == "Hello World!"



import threading
from dataclasses import dataclass
from typing import List

import anyio
from asyncer import asyncify, syncify


@dataclass
class Report:
    thread_id: int
    caller_func: str


def test_syncify_no_raise_async():
    reports: List[Report] = []

    async def do_sub_async_work():
        report = Report(
            thread_id=threading.get_ident(),
            caller_func="do_sub_async_work",
        )
        reports.append(report)

    def do_sub_sync_work():
        report = Report(
            thread_id=threading.get_ident(),
            caller_func="do_sub_sync_work",
        )
        reports.append(report)
        syncify(do_sub_async_work, raise_sync_error=False)()

    async def do_async_work():
        report = Report(
            thread_id=threading.get_ident(),
            caller_func="do_async_work",
        )
        reports.append(report)
        await asyncify(do_sub_sync_work)()

    def do_sync_work():
        own_report = Report(
            thread_id=threading.get_ident(),
            caller_func="do_sync_work",
        )
        reports.append(own_report)
        syncify(do_async_work, raise_sync_error=False)()

    async def main():
        own_report = Report(
            thread_id=threading.get_ident(),
            caller_func="main",
        )
        reports.append(own_report)
        await asyncify(do_sync_work)()

    def sync_main():
        own_report = Report(
            thread_id=threading.get_ident(),
            caller_func="sync_main",
        )
        reports.append(own_report)
        do_sync_work()

    anyio.run(main)
    sync_main()
    main_thread_id = threading.get_ident()
    assert reports[0].caller_func == "main"
    assert reports[0].thread_id == main_thread_id
    assert reports[1].caller_func == "do_sync_work"
    assert reports[1].thread_id != main_thread_id
    assert reports[2].caller_func == "do_async_work"
    assert reports[2].thread_id == main_thread_id
    assert reports[3].caller_func == "do_sub_sync_work"
    assert reports[3].thread_id != main_thread_id
    assert reports[4].caller_func == "do_sub_async_work"
    assert reports[4].thread_id == main_thread_id
    assert reports[5].caller_func == "sync_main"
    assert reports[5].thread_id == main_thread_id
    assert reports[6].caller_func == "do_sync_work"
    assert reports[6].thread_id == main_thread_id
    assert reports[7].caller_func == "do_async_work"
    assert reports[7].thread_id == main_thread_id
    assert reports[8].caller_func == "do_sub_sync_work"
    assert reports[8].thread_id != main_thread_id
    assert reports[9].caller_func == "do_sub_async_work"
    assert reports[9].thread_id == main_thread_id
